@@ -71,6 +71,7 @@ class Fitter(object):
                  language='en',
                  limiting_magnitude=None,
                  offline=False,
+                 prefer_cache=False,
                  open_in_browser=False,
                  pool=None,
                  quiet=False,
@@ -88,6 +89,7 @@ class Fitter(object):
         self._cuda = cuda
         self._limiting_magnitude = limiting_magnitude
         self._offline = offline
+        self._prefer_cache = prefer_cache
         self._open_in_browser = open_in_browser
         self._quiet = quiet
         self._test = test
@@ -265,7 +267,8 @@ class Fitter(object):
             pool = SerialPool()
         if pool.is_master():
             fetched_events = self._fetcher.fetch(
-                event_list, offline=self._offline)
+                event_list, offline=self._offline,
+                prefer_cache=self._prefer_cache)
 
             for rank in range(1, pool.size + 1):
                 pool.comm.send(fetched_events, dest=rank, tag=0)
@@ -276,11 +279,13 @@ class Fitter(object):
 
         for ei, event in enumerate(fetched_events):
             if event is not None:
-                if 'data' not in event:
-                    continue
                 self._event_name = event.get('name', 'Batch')
                 self._event_path = event.get('path', '')
-                self._event_data = event.get('data', {})
+                if not self._event_path:
+                    continue
+                self._event_data = self._fetcher.load_data(event)
+                if not self._event_data:
+                    continue
 
             if model_list:
                 lmodel_list = model_list
@@ -380,23 +385,26 @@ class Fitter(object):
                                 en = (alt_name if alt_name
                                       else self._event_name)
                                 extra_event = self._fetcher.fetch(
-                                    en, offline=self._offline)[0].get('data')
+                                    en, offline=self._offline,
+                                    prefer_cache=self._prefer_cache)[0]
+                                extra_data = self._fetcher.load_data(
+                                    extra_event)
 
                                 for rank in range(1, pool.size + 1):
-                                    pool.comm.send(extra_event, dest=rank,
+                                    pool.comm.send(extra_data, dest=rank,
                                                    tag=4)
                                 pool.close()
                             else:
-                                extra_event = pool.comm.recv(
+                                extra_data = pool.comm.recv(
                                     source=0, tag=4)
                                 pool.wait()
 
-                            if extra_event is not None:
-                                extra_event = extra_event[
-                                    list(extra_event.keys())[0]]
+                            if extra_data is not None:
+                                extra_data = extra_data[
+                                    list(extra_data.keys())[0]]
 
                                 for key in urk:
-                                    new_val = extra_event.get(key)
+                                    new_val = extra_data.get(key)
                                     self._event_data[list(
                                         self._event_data.keys())[0]][
                                             key] = new_val
