@@ -43,6 +43,7 @@ class Printer(object):
         GREEN = '\033[0;92m'
         HEADER = '\033[0;95m'
         MAGENTA = '\033[1;35m'
+        LAVENDER = '\033[38;5;189m'
         ORANGE = '\033[38;5;202m'
         RED = '\033[0;91m'
         UNDERLINE = '\033[4m'
@@ -54,6 +55,7 @@ class Printer(object):
             '!e': END,
             '!g': GREEN,
             '!m': MAGENTA,
+            '!l': LAVENDER,
             '!o': ORANGE,
             '!r': RED,
             '!u': UNDERLINE,
@@ -100,10 +102,14 @@ class Printer(object):
             pass
         else:
             self.prt(self.translate(
-                'Building strings for `{}`, please wait...'
+                'Translating strings for language `{}`, please wait '
+                '(this is only done once)...\n'
                 .format(self._language)), wrapped=True)
             self._strings = OrderedDict()
-            for key in strings:
+            for ki, key in enumerate(strings):
+                self.prt('[ {}% ]'.format(pretty_num(
+                    100.0 * ki / len(strings), sig=3)),
+                         inline=True)
                 self._strings[key] = self.translate(strings[key])
             with open_atomic(lsf, 'w') as f:
                 json.dump(self._strings, f)
@@ -381,11 +387,7 @@ class Printer(object):
         fitter = self._fitter
         outarr = [fitter._event_name]
         if desc:
-            if desc == 'burning':
-                descstr = '!o' + self._strings.get(
-                    desc, '?') + '!e'
-            else:
-                descstr = self._strings.get(desc, '?')
+            descstr = self._strings.get(desc, desc)
             outarr.append(descstr)
         if isinstance(scores, list):
             scorestring = self._strings[
